Ignore list — Kivy v1.0.1-dev documentation

# Ignore list

Ignore touch in some part on screen

class `kivy.input.postproc.ignorelist.` `InputPostprocIgnoreList`

  Bases: `object`

  InputPostprocIgnoreList is a post-processor who remove touch in ignore list. Ignore list can be configured in the Kivy config file

      [postproc]
      # Format: [(xmin, ymin, xmax, ymax), ...]
      ignore = [(0.1, 0.1, 0.15, 0.15)]

  Ignore list coordinate are in 0-1, not in the screen width/height.